<?php

class GUI_Tabs_Component extends GUI_Component {
	
	/**
	 * Tabs.
	 *
	 * @var array
	 */
	public $tabs = array();
	
	/**
	 * Arbitrary options passed to ui.tabs.js
	 *
	 * Options:
	 *   - selected: Zero-based index of the tab to be selected on initialization. Defaults to none being selected.
	 *   - event: The event bound to selecting a tab. Defaults to click.
	 *   - disabled: An array containing the position of the tabs (zero-based index) that should be disabled on initialization.
	 *   - cookie: Store last active selection in cooke. Available options: { expires: 7, path: '/', domain: 'jquery.com', secure: true }
	 *   - spinner: The HTML content of this string is shown in a tab title while remote content is loading. 
	 *   - fx: Associative array of effects. { fx: { height: 'toggle', opacity: 'toggle', duration: 'fast' } }
	 *
	 * Visit http://docs.jquery.com/UI/Tabs/tabs#options for additional option documentation.
	 */
	public $options = array();
		
	/**
	 * Change event.
	 *
	 * @var string
	 */
	public $event = 'click';
		
	/**
	 * Add a tab and its body contents.
	 *
	 * @param string $title
	 *
	 * @param string $body
	 */
	function add_tab($title, $body) {
	  $this->tabs[] = array(
				'title' => $title,
				'body' => $body,
			);
	}
	
	/**
	 * Render
	 * 
	 * WARNING: Markup is not escaped, this allows flexibility for HTML within
	 * tab titles, however be careful if tabs are generated from a user interface.
	 *
	 * @param Type $var
	 * 
	 * @return string
	 *  Markup.
	 */
	function render() {
		parent::render();
	  return theme('gui_component', $this, $this->render_tabs() . $this->render_tab_bodies());
	}
	
	/**
	 * Render only tabs.
	 *
	 * @return string
	 *  Markup.
	 */
	function render_tabs() {
		parent::render();
	  return theme('gui_tabs_component_tabs', $this);
	}
	
	/**
	 * Render only tab bodies.
	 *
	 * @return string
	 *  Markup.
	 */
	function render_tab_bodies() {
		parent::render();
		return theme('gui_tabs_component_tab_bodies', $this);	  
	}	
	
	/**
	 * Implementation of hook::add_js().
	 */
	function add_js() {
	  jquery_ui_add('ui.tabs');
	}
	
	/**
	 * Implementation of hook::add_settings().
	 */
	function add_settings() {
		$default_options = array(
				'selected' => 0,
				'spinner' => '<div class="gui-tabs-loading"></div>',
				'fx' => array(
						'height' => 'toggle',
						'opacity' => 'toggle',
						'duration' => 500,
					),
			);
	  return array(
				'options' => $this->options + $default_options,
			);
	}
			
	/**
	 * Example.
	 * 
	 * @return string
	 *  Markup.
	 */
	function example() {
		$example_content = <<<CONTENT
			Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. 
			Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. 
			Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. 
			Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
CONTENT;
		$example =& gui_get_component('tabs');
		$example->add_tab('Tab 1', $example_content);
		$example->add_tab('Tab 2', str_repeat($example_content, 2));
		$example->add_tab('Tab 3', str_repeat($example_content, 3));
		$example->add_tab('Tab 4', str_repeat($example_content, 4));

	  return $example->render();
	}
}